Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1840)

Unified Diff: chrome/browser/ui/cocoa/chooser_content_view_cocoa.h

Issue 2342723002: Reland: Update image and text color when row is selected in the chooser on Mac (Closed)
Patch Set: address comments Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/chooser_content_view_cocoa.h
diff --git a/chrome/browser/ui/cocoa/chooser_content_view_cocoa.h b/chrome/browser/ui/cocoa/chooser_content_view_cocoa.h
index a7c5b333282ed84b90e451f572f53fbbe016cf8e..f5187dba11b59a94f9b5ced9d0325c334e078540 100644
--- a/chrome/browser/ui/cocoa/chooser_content_view_cocoa.h
+++ b/chrome/browser/ui/cocoa/chooser_content_view_cocoa.h
@@ -155,13 +155,16 @@ class ChooserController;
// Called when the "Get help" button is pressed.
- (void)onHelpPressed:(id)sender;
-// Gets the image from table row view. For testing only.
+// Update the color of the image and text in the table row view.
+- (void)updateContentRowColor;
+
+// Gets the image from table row view.
Jeffrey Yasskin 2016/09/26 22:25:46 Would it make sense to say "For testing and intern
juncai 2016/09/27 22:10:48 Done.
- (NSImageView*)tableRowViewImage:(NSInteger)row;
-// Gets the text from table row view. For testing only.
+// Gets the text from table row view.
- (NSTextField*)tableRowViewText:(NSInteger)row;
-// Gets the paired status from table row view. For testing only.
+// Gets the paired status from table row view.
- (NSTextField*)tableRowViewPairedStatus:(NSInteger)row;
@end

Powered by Google App Engine
This is Rietveld 408576698